@@ -9,7 +9,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(wrap_sub);
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 our %SPEC;
 
@@ -316,7 +316,6 @@ sub wrap {
     my $meta     = { %{$args{meta}} };
     $args{convert} //= {};
     my $convert  = $args{convert};
-    my $force    = $args{force};
     $args{trap} //= 1;
     my $trap     = $args{trap};
     $args{compile} //= 1;
@@ -324,8 +323,6 @@ sub wrap {
 
     my $comppkg  = $self->{comppkg};
 
-    return [304, "Already wrapped"] if Scalar::Util::blessed($sub) && !$force;
-
     # add properties from convert, if not yet mentioned in meta
     for (keys %$convert) {
         $meta->{$_} = undef unless exists $meta->{$_};
@@ -459,9 +456,6 @@ Will wrap subroutine and bless the generated wrapped subroutine (by default into
 'Perinci::Sub::Wrapped') as a way of marking that the subroutine is a wrapped
 one.
 
-Will not wrap again (status 304) if input subroutine has already been wrapped
-(blessed the above way), unless 'force' argument is set to true.
-
 _
     result => {
         summary => 'The wrapped subroutine along with its new metadata',
@@ -500,12 +494,6 @@ So far you can convert 'args_as' and 'result_naked'.
 
 _
         },
-        force => {
-            schema => 'bool',
-            summary => 'Whether to force wrap again even '.
-                'when sub has been wrapped',
-            default => 0,
-        },
         trap => {
             schema => 'bool',
             summary => 'Whether to trap exception using an eval block',
@@ -548,7 +536,7 @@ Perinci::Sub::Wrapper - A multi-purpose subroutine wrapping framework
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
